@@ -26,8 +26,8 @@
 #include "config.h"
 #endif
 
-#include <string.h>
-#include <stdio.h>
+/* $XFree86: xc/programs/Xserver/hw/xfree86/drivers/i128/i128_driver.c,v 1.34tsi Exp $ */
+
 
 /* All drivers should typically include these */
 #include "xf86.h"
@@ -35,6 +35,7 @@
 #include "xf86Resources.h"
 
 /* All drivers need this */
+#include "xf86_ansic.h"
 
 #include "compiler.h"
 
@@ -117,7 +118,7 @@ static unsigned int I128DDC1Read(ScrnInfoPtr pScrn);
 #define I128_DRIVER_NAME "i128"
 #define I128_MAJOR_VERSION 1
 #define I128_MINOR_VERSION 2
-#define I128_PATCHLEVEL 0
+#define I128_PATCHLEVEL 1
 
 /* 
  * This contains the functions needed by the server after loading the
@@ -1191,6 +1192,7 @@ I128PreInit(ScrnInfoPtr pScrn, int flags)
 	    XF86ModReqInfo req;
 	    int errmaj, errmin;
 
+	    memset(&req, 0, sizeof(req));
 	    req.majorversion = 2;
 	    req.minorversion = 0;
             if (!LoadSubModule(pScrn->module, "exa", NULL, NULL, NULL, &req,
